@@ -229,8 +229,6 @@ struct loader_icd_term {
 
     PFN_PhysDevExt phys_dev_ext[MAX_NUM_UNKNOWN_EXTS];
     bool supports_get_dev_prop_2;
-
-    uint32_t physical_device_count;
 };
 
 // Per ICD library structure
@@ -404,8 +402,8 @@ struct loader_physical_device_term {
 };
 
 #if defined(LOADER_ENABLE_LINUX_SORT)
-// Structure for storing the relevant device information for selecting a device.
-// NOTE: Needs to be defined here so we can store this content in the term structure
+// Structure for storing the relevent device information for selecting a device.
+// NOTE: Needs to be defined here so we can store this content in the term structrue
 //       for quicker sorting.
 struct LinuxSortedDeviceInfo {
     // Associated Vulkan Physical Device
